@@ -367,6 +367,11 @@ impl ProfilerUi {
                 .on_hover_text("Turn it on with puffin::set_scopes_on(true)");
         }
 
+        if frame_view.is_empty() {
+            ui.label("No profiling data");
+            return;
+        };
+
         let mut hovered_frame = None;
 
         egui::CollapsingHeader::new("Frames")
@@ -456,8 +461,6 @@ impl ProfilerUi {
 
         let mut hovered_frame = None;
 
-        let longest_count = frames.recent.len().max(frames.slowest.len());
-
         egui::Grid::new("frame_grid").num_columns(2).show(ui, |ui| {
             ui.label("");
             ui.label("Click to select a frame, or drag to select multiple frames.");
@@ -466,13 +469,17 @@ impl ProfilerUi {
             ui.label("Recent:");
 
             Frame::dark_canvas(ui.style()).show(ui, |ui| {
-                self.show_frame_list(
-                    ui,
-                    frame_view,
-                    &frames.recent,
-                    longest_count,
-                    &mut hovered_frame,
-                );
+                egui::ScrollArea::horizontal()
+                    .stick_to_right()
+                    .show(ui, |ui| {
+                        self.show_frame_list(
+                            ui,
+                            frame_view,
+                            &frames.recent,
+                            false,
+                            &mut hovered_frame,
+                        );
+                    });
             });
 
             ui.end_row();
@@ -485,12 +492,18 @@ impl ProfilerUi {
                     frame_view.clear_slowest();
                 }
             });
+
+            // Show as many slow frames as we fit in the view:
             Frame::dark_canvas(ui.style()).show(ui, |ui| {
+                let num_fit =
+                    (ui.available_size_before_wrap().x / self.options.frame_width).floor();
+                let num_fit = (num_fit as usize).at_least(1).at_most(frames.slowest.len());
+                let slowest_of_the_slow = puffin::select_slowest(&frames.slowest, num_fit);
                 self.show_frame_list(
                     ui,
                     frame_view,
-                    &frames.slowest,
-                    longest_count,
+                    &slowest_of_the_slow,
+                    true,
                     &mut hovered_frame,
                 );
             });
@@ -504,7 +517,7 @@ impl ProfilerUi {
         ui: &mut egui::Ui,
         frame_view: &FrameView,
         frames: &[Arc<FrameData>],
-        longest_count: usize,
+        tight: bool,
         hovered_frame: &mut Option<Arc<FrameData>>,
     ) {
         let mut slowest_frame = 0;
@@ -512,15 +525,20 @@ impl ProfilerUi {
             slowest_frame = frame.duration_ns().max(slowest_frame);
         }
 
-        let desired_size = Vec2::new(
-            ui.available_size_before_wrap().x,
-            self.options.frame_list_height,
-        );
+        let frame_width_including_spacing = self.options.frame_width;
+
+        let desired_width = if tight {
+            frames.len() as f32 * frame_width_including_spacing
+        } else {
+            // leave gaps in the view for the missing frames
+            let num_frames = frames[frames.len() - 1].frame_index + 1 - frames[0].frame_index;
+            num_frames as f32 * frame_width_including_spacing
+        };
+
+        let desired_size = Vec2::new(desired_width, self.options.frame_list_height);
         let (response, painter) = ui.allocate_painter(desired_size, Sense::click_and_drag());
         let rect = response.rect;
 
-        let frame_width_including_spacing =
-            (rect.width() / (longest_count as f32)).max(4.0).min(20.0);
         let frame_spacing = 2.0;
         let frame_width = frame_width_including_spacing - frame_spacing;
 
@@ -533,7 +551,15 @@ impl ProfilerUi {
         let mut new_selection = vec![];
 
         for (i, frame) in frames.iter().enumerate() {
-            let x = rect.right() - (frames.len() as f32 - i as f32) * frame_width_including_spacing;
+            let x = if tight {
+                rect.right() - (frames.len() as f32 - i as f32) * frame_width_including_spacing
+            } else {
+                let latest_frame_index = frames[frames.len() - 1].frame_index;
+                rect.right()
+                    - (latest_frame_index + 1 - frame.frame_index) as f32
+                        * frame_width_including_spacing
+            };
+
             let frame_rect = Rect::from_min_max(
                 Pos2::new(x, rect.top()),
                 Pos2::new(x + frame_width, rect.bottom()),
@@ -607,12 +633,21 @@ fn frames_info_ui(ui: &mut egui::Ui, selection: &SelectedFrames) {
     let mut sum_scopes = 0;
     let mut sum_bytes = 0;
 
+    let mut knows_compressed_size = true;
+    let mut sum_bytes_compressed = 0;
+
     for frame in &selection.frames {
         let (min_ns, max_ns) = frame.range_ns;
         sum_ns += max_ns - min_ns;
 
         sum_scopes += frame.num_scopes;
         sum_bytes += frame.num_bytes;
+
+        if let Some(compressed_size) = frame.compressed_size {
+            sum_bytes_compressed += compressed_size;
+        } else {
+            knows_compressed_size = false;
+        }
     }
 
     let frame_indices = if selection.frames.len() == 1 {
@@ -630,12 +665,33 @@ fn frames_info_ui(ui: &mut egui::Ui, selection: &SelectedFrames) {
         format!("{} frames", selection.frames.len())
     };
 
-    ui.label(format!(
+    let mut info = format!(
         "Showing {}, {:.1} ms, {} threads, {} scopes, {:.1} kB",
         frame_indices,
         sum_ns as f64 * 1e-6,
         selection.threads.len(),
         sum_scopes,
         sum_bytes as f64 * 1e-3
-    ));
+    );
+
+    if knows_compressed_size {
+        info += &format!(" ({:.1} kB compressed)", sum_bytes_compressed as f64 * 1e-3);
+    }
+
+    if let Some(time) = format_time(selection.raw_range_ns.0) {
+        info += &format!(". Recorded {}", time);
+    }
+
+    ui.label(info);
+}
+
+fn format_time(nanos: NanoSecond) -> Option<String> {
+    let years_since_epoch = nanos / 1_000_000_000 / 60 / 60 / 24 / 365;
+    if 50 <= years_since_epoch && years_since_epoch <= 150 {
+        use chrono::TimeZone as _;
+        let datetime = chrono::Utc.timestamp(nanos / 1_000_000_000, (nanos % 1_000_000_000) as _);
+        Some(datetime.format("%Y-%m-%d %H:%M:%S%.3f UTC").to_string())
+    } else {
+        None // `nanos` is likely not counting from epoch.
+    }
 }
